@@ -1,23 +1,21 @@
 # encoding: utf8
 
 import sqlite3
-import cPickle as pickle
 import collections
 import threading
-import ast
 
-class RawLiteMap(collections.MutableMapping):
+__all__ = ['LiteMap']
+
+class LiteMap(collections.MutableMapping):
     """Persistant mapping class backed by SQLite.
     
     Only capable of mapping strings to strings; everything will be cast to a
     buffer on its way into the database and back to a str on the way out.
     
-    See the LiteMap class for storage of other types.
-    
     """
     
     def __init__(self, path, table='__main__'):
-        self._path = os.path.abspath(os.path.expanduser(path)) if path != ':memory:' else path
+        self._path = path
         self._table = self._escape(table)
         self._local = threading.local()
         
@@ -33,7 +31,7 @@ class RawLiteMap(collections.MutableMapping):
     def _escape(self, v):
         """Escapes a SQLite identifier."""
         # HACK: there must be a better way to do this (but this does appear to
-        # work just fine as long as there is no null byte).
+        # work just fine as long as there are no null byte).
         return '"%s"' % v.replace('"', '""')
     
     @property
@@ -53,7 +51,6 @@ class RawLiteMap(collections.MutableMapping):
     _dump_value = buffer
     _load_value = str
     
-    
     def setmany(self, items):
         with self._conn:
             self._conn.executemany('''INSERT INTO %s VALUES (?, ?)''' % self._table, (
@@ -77,14 +74,6 @@ class RawLiteMap(collections.MutableMapping):
         res = cur.fetchone()
         return bool(res[0])
     
-    def getmany(self, keys, *args):
-        cur = self._conn.cursor()
-        cur.execute('''SELECT key, value FROM %s WHERE key IN (%s)''' % (
-            self._table, ','.join(['?'] * len(keys))), tuple(self._dump_key(x) for x in keys))
-        map = dict(cur.fetchall())
-        res = [self._load_value(map.get(x, *args)) for x in keys]
-        return res
-    
     def __delitem__(self, key):
         cur = self._conn.cursor()
         with self._conn:
@@ -125,97 +114,25 @@ class RawLiteMap(collections.MutableMapping):
     items = lambda self: list(self.iteritems())
     keys = lambda self: list(self.iterkeys())
     values = lambda self: list(self.itervalues())
-
-
-def _is_reprable(key):
-    t = type(key)
-    return t in (int, str, unicode) or (t is tuple and all(
-        _is_reprable(x) for x in key))
-
-class LiteMap(RawLiteMap):
-    """Persistant mapping class backed by SQLite.
     
-    Values are limited to pickleable types, and mutations to stored objects
-    are not reflected in the database.
+    def update(self, *args, **kwargs):
+        self.setmany(self._update_iter(args, kwargs))
     
-    Keys may consist of strings, unicode, ints, and tuples (of these typed).
-    We are using repr to serialize the key and we are assuming that it is
-    deterministic.
-    
-    Because of the repr-ing, this does not have all of the same lookup
-    behaviours of a normal dict. Ints and longs of the same value are not
-    considered equal, nor are strings and unicode objects.
-    
-    We know this will not be deterministic across the 32/64bit platform
-    boundary when using integers > 2**32. There may be other cases that we are
-    not aware of.
-    
-    """
+    def _update_iter(self, args, kwargs):
+        """A generator to turn the args/kwargs of the update method into items.
         
-    @staticmethod
-    def _dump_key(key):
-        if not _is_reprable(key):
-            raise ValueError('cannot deterministically serialize key %r' % key)
-        return repr(key)
+        This is written in the spirit of the documentation for the dict.update
+        method.
+        
+        """
+        for arg in args:
+            if hasattr(arg, 'keys'):
+                for key in arg.keys():
+                    yield (key, arg[key])
+            else:
+                for item in arg:
+                    yield item
+        for item in kwargs.iteritems():
+            yield item
     
-    _load_key = staticmethod(lambda x: ast.literal_eval(x))
-    _dump_value = staticmethod(lambda x: buffer(pickle.dumps(x, protocol=-1)))
-    _load_value = staticmethod(lambda x: pickle.loads(str(x)))
 
-
-def test_thread_safe():
-    
-    import os
-    from threading import Thread
-    import random
-    import time
-    
-    path = ':memory:'
-    store = RawLiteMap(path)
-    
-    def target():
-        for i in xrange(100):
-            items = [(os.urandom(5), os.urandom(10)) for j in xrange(5)]
-            for k, v in items:
-                store[k] = v
-            for k, v in items:
-                assert store[k] == v
-    
-    threads = [Thread(target=target) for i in xrange(5)]
-    for x in threads:
-        x.start()
-    for x in threads:
-        x.join()
-
-    
-    
-if __name__ == '__main__':
-    
-    from time import clock as time
-    # import bsddb
-    import os
-    
-    store = LiteMap('~/Desktop/test.sqlite')
-    store.clear()
-    
-    start_time = time()
-    
-    store['key'] = 'whatever'
-    assert store['key'] == 'whatever'
-    assert 'key' in store
-    assert 'not' not in store
-    #store[('tuple', 1)] = 'tuple_1'
-    #assert store[('tuple', 1)] == 'tuple_1'
-    for i in range(100):
-        key = os.urandom(5)
-        value = os.urandom(10)
-        store[key] = value
-        assert store[key] == value, '%r != %r' % (repr(store[key]), value)
-    
-    store['a'] = 1
-    assert store.setdefault('a', 2) == 1
-    assert store['a'] == 1
-    assert store.setdefault('b', 1) == 1
-    assert store['b'] == 1
-    
-    print 'test duration:', time() - start_time
